@@ -1,5 +1,5 @@
-from django.urls import path
-from django.urls import path
+from django.urls import path, include
+from .api_router import router
 from .views import index, about, loginPage, signup, logoutPage
 
 urlpatterns = [
@@ -8,4 +8,5 @@ urlpatterns = [
     path('login/', loginPage.as_view(), name="loginPage"),
     path('signup/', signup.as_view(), name="signup"),
     path('logout/', logoutPage.as_view(), name="logout"),
+    path('api/', include(router.urls)),
 ]
\ No newline at end of file
